@@ -3,7 +3,7 @@ our $AUTHORITY = 'cpan:GENE';
 
 # ABSTRACT: Play the tabla!
 
-our $VERSION = '0.0400';
+our $VERSION = '0.0401';
 
 use Moo;
 use File::ShareDir qw(dist_dir);
@@ -53,14 +53,9 @@ sub strike {
     my ($self, $bol, $dura, $index) = @_;
     my $patches = $self->patches->{$bol};
     my $patch = _patch_index($patches, $index);
-    $self->_strike($dura, $patch);
-}
-
-sub _strike {
-    my ($self, $dura, $pitch) = @_;
+    $patch ||= 60;
     $dura  ||= $self->quarter;
-    $pitch ||= 60;
-    $self->note($dura, $pitch);
+    $self->note($dura, $patch);
 }
 
 sub _patch_index {
@@ -83,7 +78,7 @@ Music::Percussion::Tabla - Play the tabla!
 
 =head1 VERSION
 
-version 0.0400
+version 0.0401
 
 =head1 SYNOPSIS
 
